@@ -7,18 +7,18 @@ Hyper Fast and safe image manipulation library for python . Powered by rust.
 :license: MIT, see LICENSE for more details.
 """
 
-from .polaroid import Image, Rgb, Gif, ImageDraw, Rgba
+from .polaroid import Image, Rgb, Gif, Rgba
 from collections import namedtuple
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 __author__ = "Daggy1234"
 __license__ = "MIT"
-__copyright__ = "Copyright 2020 Daggy1234"
+__copyright__ = "Copyright 2021 Daggy1234"
 
-__all__ = ["Image", "Rgb", "Gif", "ImageDraw"]
+__all__ = ["Image", "Rgb", "Gif", "Rgba"]
 
 VersionInfo = namedtuple('VersionInfo',
                          'major minor micro releaselevel serial')
 
-version_info = VersionInfo(major=0, minor=3, micro=0, releaselevel='development',
+version_info = VersionInfo(major=0, minor=3, micro=1, releaselevel='development',
                            serial=0)
